# -*- coding: utf-8 -*-

from rest_framework import serializers
from thx.api.serializers import (
    ThuxCreateSerializerMixin, ThuxDisableSerializerMixin, ThuxEnableSerializerMixin, ThuxListSerializerMixin,
    ThuxPartialUpdateSerializerMixin, ThuxRetrieveSerializerMixin, ThuxUpdateSerializerMixin,
)
from thx.role.core.serializers import ThuxRoleSerializerMixin

from ... import models


# PAYMENT FORM
class PaymentFormSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_payment_payment_form'
        model = models.PaymentForm
        fields = '__all__'


class PaymentFormListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_payment_payment_form_list'
        model = models.PaymentForm
        fields = '__all__'


class PaymentFormRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_payment_payment_form_retrieve'
        model = models.PaymentForm
        fields = '__all__'


class PaymentFormCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_payment_payment_form_create'
        model = models.PaymentForm
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = PaymentFormRetrieveSerializer


class PaymentFormUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_payment_payment_form_update'
        model = models.PaymentForm
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = PaymentFormRetrieveSerializer


class PaymentFormPartialUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_payment_payment_form_partial_update'
        model = models.PaymentForm
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = PaymentFormRetrieveSerializer


class PaymentFormEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_payment_payment_form_enable'
        model = models.PaymentForm
        fields = ()
        response_serializer = PaymentFormRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class PaymentFormDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_payment_payment_form_disable'
        model = models.PaymentForm
        fields = ()
        response_serializer = PaymentFormRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class PaymentFormLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_payment_payment_form_light'
        model = models.PaymentForm
        fields = ('id', 'status', 'status_display',)


# PAYMENT INSTALLMENT
class PaymentInstallmentSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_payment_payment_installment'
        model = models.PaymentInstallment
        fields = '__all__'


class PaymentInstallmentListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    payment_form = PaymentFormRetrieveSerializer()

    class Meta:
        ref_name = 'v1_payment_payment_installment_list'
        model = models.PaymentInstallment
        fields = '__all__'


class PaymentInstallmentRetrieveSerializer(
    ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer
):
    payment_form = PaymentFormRetrieveSerializer()

    class Meta:
        ref_name = 'v1_payment_payment_installment_retrieve'
        model = models.PaymentInstallment
        fields = '__all__'


class PaymentInstallmentCreateSerializer(
    ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_payment_payment_installment_create'
        model = models.PaymentInstallment
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = PaymentInstallmentRetrieveSerializer


class PaymentInstallmentUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_payment_payment_installment_update'
        model = models.PaymentInstallment
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = PaymentInstallmentRetrieveSerializer


class PaymentInstallmentPartialUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_payment_payment_installment_partial_update'
        model = models.PaymentInstallment
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = PaymentInstallmentRetrieveSerializer


class PaymentInstallmentEnableSerializer(
    ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_payment_payment_installment_enable'
        model = models.PaymentInstallment
        fields = ()
        response_serializer = PaymentInstallmentRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class PaymentInstallmentDisableSerializer(
    ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_payment_payment_installment_disable'
        model = models.PaymentInstallment
        fields = ()
        response_serializer = PaymentInstallmentRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class PaymentInstallmentLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_payment_payment_installment_light'
        model = models.PaymentInstallment
        fields = ('id', 'status', 'status_display',)
